@@ -6,7 +6,7 @@ import logging
 from nanoplot.version import __version__
 from argparse import HelpFormatter, Action, ArgumentParser
 import textwrap as _textwrap
-import matplotlib.pyplot as plt
+import pandas as pd
 
 
 class CustomHelpFormatter(HelpFormatter):
@@ -39,7 +39,6 @@ class Action_Print_Colors(Action):
 
 
 class Action_Print_Colormaps(Action):
-
     def __init__(self, option_strings, dest="==SUPPRESS==", default="==SUPPRESS==", help=None):
         super(Action_Print_Colormaps, self).__init__(
             option_strings=option_strings,
@@ -155,18 +154,22 @@ def get_args():
     visual.add_argument("-cm", "--colormap",
                         help="Specify a valid matplotlib colormap for the heatmap",
                         default="Greens")
-    visual.add_argument("-f", "--format",
-                        help="Specify the output format of the plots.",
-                        default="png",
-                        type=str,
-                        choices=['eps', 'jpeg', 'jpg', 'pdf', 'pgf', 'png', 'ps',
-                                 'raw', 'rgba', 'svg', 'svgz', 'tif', 'tiff'])
+    # visual.add_argument("-f", "--format",
+    #                     help="Specify the output format of the plots.",
+    #                     default="png",
+    #                     type=str,
+    #                     choices=['eps', 'jpeg', 'jpg', 'pdf', 'pgf', 'png', 'ps',
+    #                              'raw', 'rgba', 'svg', 'svgz', 'tif', 'tiff'])
     visual.add_argument("--plots",
                         help="Specify which bivariate plots have to be made.",
                         default=['kde', 'dot'],
                         type=str,
                         nargs='*',
-                        choices=['kde', 'hex', 'dot', 'pauvre'])
+                        choices=['kde', 'hex', 'dot'])
+    visual.add_argument("--legacy", help="Specify which bivariate plots have to be made (legacy mode).",
+                        type=str,
+                        nargs='*',
+                        choices=['kde', 'dot', 'hex'])
     visual.add_argument("--listcolors",
                         help="List the colors which are available for plotting and exit.",
                         action=Action_Print_Colors,
@@ -267,13 +270,19 @@ def custom_formatter(prog):
 
 def list_colors():
     parent_directory = os.path.dirname(os.path.abspath(os.path.dirname(__file__)))
-    colours = open(os.path.join(parent_directory, "extra/color_options.txt")).readlines()
-    print("{}".format(", ".join([c.strip() for c in colours])))
+    colours = open(os.path.join(parent_directory, "extra/color_options_hex.txt"))
+    col_hex = {}
+
+    for line in colours:
+        key, value = line.split(",")
+        col_hex[key] = value.strip()
+    print("Valid colors: {}".format("\n".join([c.strip() for c in list(col_hex.keys())])))
     sys.exit(0)
 
 
 def list_colormaps():
-    print(', '.join(plt.colormaps()))
+    print('Valid colormaps:\nGreys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,'
+          'Rainbow,Portland,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividis')
     sys.exit(0)
 
 
@@ -299,3 +308,28 @@ def init_logs(args, tool="NanoPlot"):
     logging.info('{} {} started with arguments {}'.format(tool, __version__, args))
     logging.info('Python version is: {}'.format(sys.version.replace('\n', ' ')))
     return logname
+
+
+def subsample_datasets(df, minimal=10000):
+    if 'dataset' in df:
+        list_df = []
+
+        for d in df["dataset"].unique():
+            dataset = df.loc[df['dataset'] == d]
+
+            if len(dataset.index) < minimal:
+                list_df.append(dataset)
+
+            else:
+                list_df.append(dataset.sample(minimal))
+
+        subsampled_df = pd.concat(list_df, ignore_index=True)
+
+    else:
+        if len(df.index) < minimal:
+            subsampled_df = df
+
+        else:
+            subsampled_df = df.sample(minimal)
+
+    return subsampled_df
