@@ -1,8 +1,11 @@
+import os
 from base64 import b64encode
 from io import BytesIO
+from pathlib import Path
 from urllib.parse import quote as urlquote
 import sys
 from kaleido.scopes.plotly import PlotlyScope
+import logging
 
 
 class Plot(object):
@@ -39,7 +42,16 @@ class Plot(object):
         if self.html:
             with open(self.path, 'w') as html_out:
                 html_out.write(self.html)
-            self.save_static()
+            try:
+                self.save_static()
+            except (AttributeError, ValueError) as e:
+                p = os.path.splitext(self.path)[0]+".png"
+                if os.path.exists(p):
+                    os.remove(p)
+
+                logging.warning("No static plots are saved due to some kaleido problem:")
+                logging.warning(e)
+
         elif self.fig:
             self.fig.savefig(
                 fname=self.path,
